@@ -1,19 +1,19 @@
-import ctypes
-import math
-import warnings
+import base64
+import tempfile
+
+from vaex.strings import array
+
+import lightgbm
+
+import numpy as np
+
+import traitlets
 
 import vaex
-import lightgbm
-import numpy as np
-import tempfile
-import base64
 import vaex.serialize
-from . import state
-import traitlets
+
 from . import generate
-
-
-lib = lightgbm.basic._LIB
+from . import state
 
 
 @vaex.serialize.register
@@ -60,6 +60,7 @@ class LightGBMModel(state.HasState):
      1            3               4.6             6.1            1.4         1    [0.00182039 0.98491357 0.01326604]
      2            2.9             4.6             6.6            1.3         1    [2.50915444e-04 9.98431777e-01 1.31730785e-03]
     '''
+    snake_name = 'lightgbm_model'
     features = traitlets.List(traitlets.Unicode(), help='List of features to use when fitting the LightGBMModel.')
     target = traitlets.Unicode(allow_none=False, help='The name of the target column.')
     num_boost_round = traitlets.CInt(help='Number of boosting iterations.')
@@ -67,7 +68,7 @@ class LightGBMModel(state.HasState):
     prediction_name = traitlets.Unicode(default_value='lightgbm_prediction', help='The name of the virtual column housing the predictions.')
 
     def __call__(self, *args):
-        data2d = np.vstack([arg.astype(np.float64) for arg in args]).T.copy()
+        data2d = np.stack([np.asarray(arg, np.float64) for arg in args], axis=1)
         return self.booster.predict(data2d)
 
     def transform(self, df):
@@ -85,8 +86,7 @@ class LightGBMModel(state.HasState):
         copy.add_virtual_column(self.prediction_name, expression, unique=False)
         return copy
 
-    def fit(self, df, valid_sets=None, valid_names=None, early_stopping_rounds=None, evals_result=None, verbose_eval=None,
-            copy=False, **kwargs):
+    def fit(self, df, valid_sets=None, valid_names=None, early_stopping_rounds=None, evals_result=None, verbose_eval=None, **kwargs):
         """Fit the LightGBMModel to the DataFrame.
 
         The model will train until the validation score stops improving.
@@ -103,26 +103,14 @@ class LightGBMModel(state.HasState):
         :param dict evals_result: A dictionary storing the evaluation results of all *valid_sets*.
         :param bool verbose_eval: Requires at least one item in *valid_sets*.
             If *verbose_eval* is True then the evaluation metric on the validation set is printed at each boosting stage.
-        :param bool copy: (default, False) If True, make an in memory copy of the data before passing it to LightGBMModel.
         """
 
-        if copy:
-            dtrain = lightgbm.Dataset(df[self.features].values, df.evaluate(self.target))
-            if valid_sets is not None:
-                for i, item in enumerate(valid_sets):
-                    valid_sets[i] = lightgbm.Dataset(item[self.features].values, item[self.target].values)
-            else:
-                valid_sets = ()
+        dtrain = lightgbm.Dataset(df[self.features].values, df[self.target].to_numpy())
+        if valid_sets is not None:
+            for i, item in enumerate(valid_sets):
+                valid_sets[i] = lightgbm.Dataset(item[self.features].values, item[self.target].to_numpy())
         else:
-            dtrain = VaexDataset(df, self.target, features=self.features)
-            if valid_sets is not None:
-                for i, item in enumerate(valid_sets):
-                    # valid_sets[i] = VaexDataset(item, self.target, features=self.features)
-                    valid_sets[i] = lightgbm.Dataset(item[self.features].values, item[self.target].values)
-                    warnings.warn('''Validation sets do not obey the `copy=False` argument.
-                                  A standard in-memory copy is made for each validation set.''', UserWarning)
-            else:
-                valid_sets = ()
+            valid_sets = ()
 
         self.booster = lightgbm.train(params=self.params,
                                       train_set=dtrain,
@@ -163,69 +151,9 @@ class LightGBMModel(state.HasState):
         self.booster = lightgbm.Booster(model_file=filename)
 
 
-class VaexDataset(lightgbm.Dataset):
-    def __init__(self, df, label=None, features=None, blocksize=100*1000, sample_count=10*100, params={}):
-        super(VaexDataset, self).__init__(None)
-        self.df = df
-        self.features = features or self.df.get_column_names(virtual=True)
-        assert len(set(self.features)) == len(self.features), "using duplicate features"
-        self.blocksize = blocksize
-
-        self.data_references = {}
-
-        self.c_features = (ctypes.c_char_p * len(self.features))()
-        self.c_features[:] = [k.encode() for k in self.features]
-
-        self.handle = ctypes.c_void_p()
-
-        row_count = len(self.df)
-        ncol = len(self.features)
-        num_sample_row = min(sample_count, row_count)
-
-        data_list = [self.df.evaluate(k, i1=0, i2=num_sample_row).astype(np.float64) for k in self.features]
-        data_pointers = [k.ctypes.data_as(ctypes.POINTER(ctypes.c_double)) for k in data_list]
-        sample_data = (ctypes.POINTER(ctypes.c_double) * ncol)(*data_pointers)
-
-        indices = np.arange(num_sample_row, dtype=np.int32)
-        indices_pointers = [indices.ctypes.data_as(ctypes.POINTER(ctypes.c_int)) for k in range(ncol)]
-        sample_indices = (ctypes.POINTER(ctypes.c_int) * ncol)(*indices_pointers)
-        num_per_col = (ctypes.c_int * ncol)(*((num_sample_row,) * ncol))
-        parameters = ctypes.c_char_p(lightgbm.basic.param_dict_to_str(params).encode())
-
-        lightgbm.basic._safe_call(lib.LGBM_DatasetCreateFromSampledColumn(sample_data,
-                                                                          sample_indices,
-                                                                          ctypes.c_uint(ncol),
-                                                                          num_per_col,
-                                                                          ctypes.c_uint(num_sample_row),
-                                                                          ctypes.c_uint(row_count),
-                                                                          parameters,
-                                                                          ctypes.byref(self.handle)))
-
-        blocks = int(math.ceil(row_count / blocksize))
-        dtype = np.float64
-        for i in range(blocks):
-            i1 = i * blocksize
-            i2 = min(row_count, (i+1) * blocksize)
-            data = np.array([df.evaluate(k, i1=i1, i2=i2).astype(dtype) for k in self.features]).T.copy()
-            ctypemap = {np.float64: ctypes.c_double, np.float32: ctypes.c_float}
-            capi_typemap = {np.float64: lightgbm.basic.C_API_DTYPE_FLOAT64, np.float32: lightgbm.basic.C_API_DTYPE_FLOAT32}
-            lightgbm.basic._safe_call(lib.LGBM_DatasetPushRows(self.handle,
-                                                               data.ctypes.data_as(ctypes.POINTER(ctypemap[dtype])),
-                                                               ctypes.c_uint(capi_typemap[dtype]),
-                                                               ctypes.c_uint32(i2-i1),
-                                                               ctypes.c_uint32(ncol),
-                                                               ctypes.c_uint32(i1),
-                                                               ))
-
-        if label is not None:
-            self.label_data = self.df.evaluate(label)
-            self.set_label(self.label_data)
-
-
 if __name__ == "__main__":
     df = vaex.ml.iris()
     features = ['sepal_length', 'sepal_width', 'petal_length', 'petal_width']
-    # ldf = VaexDataset(df, 'class_', features=features)
     ldf = lightgbm.Dataset(np.array(df[features]), df.data.class_)
     param = {'num_leaves': 31, 'num_trees': 100, 'objective': 'softmax', 'num_class': 3}
     num_boost_round = 30
