@@ -226,7 +226,7 @@ class IncrementalPredictor(state.HasState):
 
         n_samples = len(df)
 
-        progressbar = vaex.utils.progressbars(progress)
+        progressbar = vaex.utils.progressbars(progress, title="fit(sklearn)")
 
         # Portions of the DataFrame to evaluate
         expressions = self.features + [self.target]
