@@ -54,7 +54,7 @@ class XGBoostModel(state.HasState):
     1             6.1            3               4.6            1.4         1                     1
     2             6.6            2.9             4.6            1.3         1                     1
     '''
-
+    snake_name = 'xgboost_model'
     features = traitlets.List(traitlets.Unicode(), help='List of features to use when fitting the XGBoostModel.')
     target = traitlets.Unicode(allow_none=False, help='The name of the target column.')
     num_boost_round = traitlets.CInt(help='Number of boosting iterations.')
@@ -62,7 +62,7 @@ class XGBoostModel(state.HasState):
     prediction_name = traitlets.Unicode(default_value='xgboost_prediction', help='The name of the virtual column housing the predictions.')
 
     def __call__(self, *args):
-        data2d = np.vstack([arg.astype(np.float64) for arg in args]).T.copy()
+        data2d = np.stack([np.asarray(arg, np.float64) for arg in args], axis=1)
         dmatrix = xgboost.DMatrix(data2d)
         return self.booster.predict(dmatrix)
 
@@ -97,13 +97,13 @@ class XGBoostModel(state.HasState):
         '''
 
         data = df[self.features].values
-        target_data = df.evaluate(self.target)
+        target_data = df[self.target].to_numpy()
         dtrain = xgboost.DMatrix(data, target_data)
         if evals is not None:
             evals = [list(elem) for elem in evals]
             for item in evals:
                 data = item[0][self.features].values
-                target_data = item[0].evaluate(self.target)
+                target_data = item[0][self.target].to_numpy()
                 item[0] = xgboost.DMatrix(data, target_data)
         else:
             evals = ()
